Class: HighLevel::Resources::CustomMenus
- Defined in:
- lib/high_level/resources/custom_menus.rb
Instance Method Summary collapse
-
#create_custom_menu(body:, **_opts) ⇒ Object
Create Custom Menu Link.
-
#delete_custom_menu(custom_menu_id:, **_opts) ⇒ Object
Delete Custom Menu Link.
-
#get_custom_menu_by_id(custom_menu_id:, **_opts) ⇒ Object
Get Custom Menu Link.
-
#get_custom_menus(location_id: nil, skip: nil, limit: nil, query: nil, show_on_company: nil, **_opts) ⇒ Object
Get Custom Menu Links.
-
#update_custom_menu(custom_menu_id:, body:, **_opts) ⇒ Object
Update Custom Menu Link.
Methods inherited from Base
Constructor Details
This class inherits a constructor from HighLevel::Resources::Base
Instance Method Details
#create_custom_menu(body:, **_opts) ⇒ Object
Create Custom Menu Link
Creates a new custom menu for a company. Requires authentication and proper permissions. For Icon Usage Details please refer to doc.clickup.com/8631005/d/h/87cpx-243696/d60fa70db6b92b2
58 59 60 61 62 63 64 65 |
# File 'lib/high_level/resources/custom_menus.rb', line 58 def (body:, **_opts) request( method: :post, path: "/custom-menus/", security: ["Agency-Access"], body: body ) end |
#delete_custom_menu(custom_menu_id:, **_opts) ⇒ Object
Delete Custom Menu Link
Removes a specific custom menu from the system. This operation requires authentication and proper permissions. The custom menu is identified by its unique ID, and the operation is performed within the context of a specific company.
35 36 37 38 39 40 41 |
# File 'lib/high_level/resources/custom_menus.rb', line 35 def (custom_menu_id:, **_opts) request( method: :delete, path: "/custom-menus/#{}", security: ["Agency-Access"] ) end |
#get_custom_menu_by_id(custom_menu_id:, **_opts) ⇒ Object
Get Custom Menu Link
Fetches a single custom menus based on id. This endpoint allows clients to retrieve custom menu configurations, which may include menu items, categories, and associated metadata
12 13 14 15 16 17 18 |
# File 'lib/high_level/resources/custom_menus.rb', line 12 def (custom_menu_id:, **_opts) request( method: :get, path: "/custom-menus/#{}", security: ["Agency-Access"] ) end |
#get_custom_menus(location_id: nil, skip: nil, limit: nil, query: nil, show_on_company: nil, **_opts) ⇒ Object
Get Custom Menu Links
Fetches a collection of custom menus based on specified criteria. This endpoint allows clients to retrieve custom menu configurations, which may include menu items, categories, and associated metadata. The response can be tailored using query parameters for filtering, sorting, and pagination.
46 47 48 49 50 51 52 53 |
# File 'lib/high_level/resources/custom_menus.rb', line 46 def (location_id: nil, skip: nil, limit: nil, query: nil, show_on_company: nil, **_opts) request( method: :get, path: "/custom-menus/", security: ["Agency-Access"], params: { "locationId" => location_id, "skip" => skip, "limit" => limit, "query" => query, "showOnCompany" => show_on_company }.compact ) end |
#update_custom_menu(custom_menu_id:, body:, **_opts) ⇒ Object
Update Custom Menu Link
Updates an existing custom menu for a given company. Requires authentication and proper permissions.
23 24 25 26 27 28 29 30 |
# File 'lib/high_level/resources/custom_menus.rb', line 23 def (custom_menu_id:, body:, **_opts) request( method: :put, path: "/custom-menus/#{}", security: ["Agency-Access"], body: body ) end |